@@ -151,14 +151,9 @@ static void
 bar_start (GooCanvas *theCanvas)
 {
   GcomprisProperties *properties = gc_prop_get();
-  gint16       height;
-  gint16       buttony;
-  double       zoom;
   RsvgHandle  *svg_handle;
   GooCanvasBounds bounds;
 
-  height = BARHEIGHT-2;
-
   _default_y = BOARDHEIGHT - BARHEIGHT;
   _default_zoom = 1.0;
 
@@ -174,10 +169,6 @@ bar_start (GooCanvas *theCanvas)
 				 NULL);
   SET_ITEM_LOCATION(bar_item, 0, 0);
 
-  goo_canvas_item_get_bounds(bar_item, &bounds);
-  zoom = (double)(height-BAR_GAP)/(bounds.y2 - bounds.y1);
-  buttony = (height-(bounds.y2 - bounds.y1)*zoom)/2 - 20;
-
   /*
    * The Order in which buttons are created represents
    * also the order in which they will be displayed
@@ -521,9 +512,6 @@ static gchar *bar_flags_to_name(GComprisBarFlags flag)
     case GC_BAR_HELP:
       result = "help";
       break;
-    default:
-      result = NULL;
-      break;
     }
   return result;
 }
@@ -536,17 +524,12 @@ static gint bar_play_sound (GooCanvasItem *item)
 {
   int policy = gc_sound_policy_get();
   gchar *str;
+  gc_sound_policy_set(PLAY_ONLY_IF_IDLE);
 
   GComprisBarFlags flag =
     GPOINTER_TO_UINT(g_object_get_data(G_OBJECT (item), "flag"));
-
-  gchar *button_name = bar_flags_to_name(flag);
-  if (button_name == NULL)
-    return (FALSE);
-
-  gc_sound_policy_set(PLAY_ONLY_IF_IDLE);
-
-  str = g_strdup_printf("voices/$LOCALE/misc/%s.ogg", button_name);
+  str = g_strdup_printf("voices/$LOCALE/misc/%s.ogg",
+			bar_flags_to_name(flag));
 
   gc_sound_play_ogg(str, NULL);
 
