@@ -25,6 +25,11 @@
 #include <string.h>
 #include "binreloc.h"
 
+#ifdef MAC_INTEGRATION
+#include <igemacintegration/ige-mac-bundle.h>
+static IgeMacBundle *bundle = NULL;
+#endif
+
 G_BEGIN_DECLS
 
 
@@ -40,6 +45,45 @@ _br_find_exe (GbrInitError *error)
 	if (error)
 		*error = GBR_INIT_ERROR_DISABLED;
 	return NULL;
+#else
+#ifdef WIN32
+	/* I *thought* this program code already included the
+	   relocation code for windows. Unfortunately this is not
+	   the case and we have to add this manually. This is only
+	   one possibility; other ways of looking up the full path
+	   of gcompris-bin.exe probably exist.*/
+	gchar *prefix;
+	gchar *result;
+
+	/* From the glib docs: When passed NULL, this function looks
+	   up installation the directory of the main executable of
+	   the current process */
+	prefix = g_win32_get_package_installation_directory_of_module (NULL);
+	result = g_build_filename (prefix,
+				   "bin", "gcompris.exe",
+				   (char*)NULL);
+	g_free (prefix);
+	return result;
+#elif MAC_INTEGRATION
+	gchar *prefix = NULL, *result = NULL;
+	g_type_init();
+	bundle = ige_mac_bundle_new();
+	if (!bundle) {
+	  *error = GBR_INIT_ERROR_MAC_NOT_BUNDLE;
+	  return NULL;
+	}
+	if (!ige_mac_bundle_get_is_app_bundle (bundle)) {
+	  g_object_unref(bundle);
+	  bundle = NULL;
+	  *error = GBR_INIT_ERROR_MAC_NOT_APP_BUNDLE;
+	  return NULL;
+	}
+	ige_mac_bundle_setup_environment(bundle);
+	prefix = g_strdup(ige_mac_bundle_get_path(bundle));
+	result = g_build_filename(prefix, "Contents/MacOS",
+				  "GCompris-bin", NULL);
+	g_free(prefix);
+	return result;
 #else
 	char *path, *path2, *line, *result;
 	size_t buf_size;
@@ -164,6 +208,7 @@ _br_find_exe (GbrInitError *error)
 	g_free (line);
 	fclose (f);
 	return path;
+#endif /* G_OS_WINDOWS */
 #endif /* ENABLE_BINRELOC */
 }
 
@@ -555,7 +600,11 @@ gbr_find_data_dir (const gchar *default_data_dir)
 			return NULL;
 	}
 
+#ifdef MAC_INTEGRATION
+	dir = g_strdup(ige_mac_bundle_get_datadir(bundle));
+#else
 	dir = g_build_filename (prefix, "share", NULL);
+#endif
 	g_free (prefix);
 	return dir;
 }
@@ -588,7 +637,11 @@ gbr_find_locale_dir (const gchar *default_locale_dir)
 			return NULL;
 	}
 
+#ifdef MAC_INTEGRATION
+	dir = g_strdup(ige_mac_bundle_get_localedir(bundle));
+#else
 	dir = g_build_filename (data_dir, "locale", NULL);
+#endif
 	g_free (data_dir);
 	return dir;
 }
@@ -621,10 +674,15 @@ gbr_find_lib_dir (const gchar *default_lib_dir)
 			return NULL;
 	}
 
+#ifdef MAC_INTEGRATION
+	dir = g_build_filename(ige_mac_bundle_get_datadir(bundle),
+			       "..", "lib", NULL);
+#else
 	if (default_lib_dir && strstr(default_lib_dir, "lib64"))
 		dir = g_build_filename (prefix, "lib64", NULL);
 	else
 		dir = g_build_filename (prefix, "lib", NULL);
+#endif
 	g_free (prefix);
 	return dir;
 }
