@@ -30,7 +30,6 @@
 #include <libxml/parserInternals.h>
 
 #include "gcompris.h"
-#include "sugar_gc.h"
 
 #ifdef WIN32
 #define realpath(N,R) _fullpath((R),(N),_MAX_PATH)
@@ -124,8 +123,6 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
   pixmapfile = g_strdup_vprintf (format, args);
   va_end (args);
 
-  pixmapfile = sugar_get_journal_file(pixmapfile);
-
   /* Search */
   filename = gc_file_find_absolute(pixmapfile);
 
@@ -292,7 +289,6 @@ void gc_item_focus_init(GooCanvasItem *source_item,
 {
   GooCanvasItem *highlight_item;
   GooCanvasBounds bounds;
-  gboolean already_created = FALSE;
 
   if(!target_item)
     target_item = source_item;
@@ -309,7 +305,6 @@ void gc_item_focus_init(GooCanvasItem *source_item,
 
   if(highlight_item)
     {
-      already_created = TRUE;
       goo_canvas_item_remove(highlight_item);
     }
 
@@ -443,7 +438,6 @@ gc_item_rotate_relative(GooCanvasItem *item, double angle)
 {
   double x1, x2, y1, y2;
   double tx1, tx2, ty1, ty2;
-  double cx, cy;
 
   //  goo_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
   /* WARNING: Do not use goo_canvas_item_get_bounds which gives unpredictable results */
@@ -481,10 +475,6 @@ gc_item_rotate_relative(GooCanvasItem *item, double angle)
   x2 = MAX(tx1,tx2);
   y2 = MAX(ty1,ty2);
 
-
-  cx = (x2+x1)/2;
-  cy = (y2+y1)/2;
-
   goo_canvas_item_rotate(item, angle,
 			 x1+(x2-x1)/2,
 			 y1+(y2-y1)/2);
@@ -571,7 +561,7 @@ gc_file_find_absolute(const gchar *format, ...)
   int			 i = 0;
   gchar			*filename;
   gchar			*absolute_filename;
-  gchar			*dir_to_search[6];
+  gchar			*dir_to_search[4];
   GcomprisProperties	*properties = gc_prop_get();
 
   if (!format)
@@ -594,8 +584,6 @@ gc_file_find_absolute(const gchar *format, ...)
   dir_to_search[i++] = properties->user_dir;
   dir_to_search[i++] = properties->package_data_dir;
   dir_to_search[i++] = properties->package_skin_dir;
-  if(properties->package_extra_data_dir)
-    dir_to_search[i++] = properties->package_extra_data_dir;
   dir_to_search[i++] = NULL;
 
   absolute_filename = g_strdup(filename);
