@@ -47,7 +47,6 @@
 #include "gcompris_config.h"
 #include "about.h"
 #include "bar.h"
-#include "sugar_gc.h"
 #include "status.h"
 #include <locale.h>
 
@@ -71,6 +70,8 @@ gchar * exec_prefix = NULL;
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void map_cb  (GtkWidget *widget, gpointer data);
+static gboolean _realize_callback (GtkWidget *widget, GdkEventExpose *event,
+				   gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
@@ -116,7 +117,6 @@ static gint popt_fullscreen	   = FALSE;
 static gint popt_window		   = FALSE;
 static gint popt_sound		   = FALSE;
 static gint popt_mute		   = FALSE;
-static gint popt_mute_music    = FALSE;
 static gint popt_cursor		   = FALSE;
 static gint popt_nocursor	   = FALSE;
 static gint popt_version	   = FALSE;
@@ -125,7 +125,6 @@ static gint popt_debug		   = FALSE;
 static gint popt_nolockcheck	   = FALSE;
 static gchar *popt_root_menu       = NULL;
 static gchar *popt_package_data_dir = NULL;
-static gchar *popt_package_extra_data_dir = NULL;
 static gchar *popt_package_skin_dir = NULL;
 static gchar *popt_plugin_dir      = NULL;
 static gchar *popt_python_plugin_dir = NULL;
@@ -147,6 +146,9 @@ static gchar *popt_server          = NULL;
 static gint  *popt_web_only        = NULL;
 static gchar *popt_cache_dir       = NULL;
 static gchar *popt_drag_mode       = NULL;
+static gchar *sugarBundleId        = NULL;
+static gchar *sugarActivityId      = NULL;
+static gint popt_sugar_look        = FALSE;
 static gint popt_no_zoom           = FALSE;
 static gdouble popt_timing_base    = 1.0;
 static gdouble popt_timing_mult    = 1.0;
@@ -164,9 +166,6 @@ static GOptionEntry options[] = {
   {"mute", 'm', 0, G_OPTION_ARG_NONE, &popt_mute,
    N_("run GCompris without sound."), NULL},
 
-  {"mute_music", '\0', 0, G_OPTION_ARG_NONE, &popt_mute_music,
-   N_("run GCompris without music."), NULL},
-
   {"cursor", 'c', 0, G_OPTION_ARG_NONE, &popt_cursor,
    N_("run GCompris with the default system cursor."), NULL},
 
@@ -190,9 +189,6 @@ static GOptionEntry options[] = {
   {"package_data_dir", 'A', 0, G_OPTION_ARG_STRING, &popt_package_data_dir,
    N_("GCompris will find the data dir in this directory"), NULL},
 
-  {"package_extra_data_dir", 0, 0, G_OPTION_ARG_STRING, &popt_package_extra_data_dir,
-   N_("GCompris will find the extra data dir in this directory"), NULL},
-
   {"package_skin_dir", 'S', 0, G_OPTION_ARG_STRING, &popt_package_skin_dir,
    N_("GCompris will find the skins in this directory"), NULL},
 
@@ -260,6 +256,15 @@ static GOptionEntry options[] = {
   {"nolockcheck", '\0', 0, G_OPTION_ARG_NONE, &popt_nolockcheck,
    N_("Do not avoid the execution of multiple instances of GCompris."), NULL},
 
+  {"sugarBundleId", '\0', 0, G_OPTION_ARG_STRING, &sugarBundleId,
+   "Sugar Bundle Id", NULL},
+
+  {"sugarActivityId", '\0', 0, G_OPTION_ARG_STRING, &sugarActivityId,
+   "Sugar Activity Id", NULL},
+
+  {"sugar",'\0', 0, G_OPTION_ARG_NONE, &popt_sugar_look,
+   ("Use Sugar DE look&feel"), NULL},
+
   {"no-zoom",'\0', 0, G_OPTION_ARG_NONE, &popt_no_zoom,
    ("Disable maximization zoom"), NULL},
 
@@ -678,6 +683,34 @@ gc_set_default_background(GooCanvasItem *parent)
 			  "#BACKGROUND");
 }
 
+static gboolean
+_realize_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data)
+{
+#ifdef USE_SUGAR
+  Window xwindow = GDK_WINDOW_XWINDOW(window->window);
+  /*
+   * Sugar requires properties to be set before the windows is realized
+   */
+  if (sugarBundleId)
+    XChangeProperty(GDK_DISPLAY(),
+		    xwindow,
+		    XInternAtom(GDK_DISPLAY(), "_SUGAR_BUNDLE_ID", 0),
+		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
+		    PropModeReplace,
+		    (unsigned char *) sugarBundleId, strlen(sugarBundleId));
+
+  if (sugarActivityId)
+    XChangeProperty(GDK_DISPLAY(),
+		    xwindow,
+		    XInternAtom(GDK_DISPLAY(), "_SUGAR_ACTIVITY_ID", 0),
+		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
+		    PropModeReplace,
+		    (unsigned char *) sugarActivityId, strlen(sugarActivityId));
+#endif
+
+  return FALSE;
+}
+
 static void
 init_workspace()
 {
@@ -799,6 +832,8 @@ static void setup_window ()
 
   gtk_window_set_default_size(GTK_WINDOW(window), BOARDWIDTH, BOARDHEIGHT);
   gtk_window_set_wmclass(GTK_WINDOW(window), "gcompris", "GCompris");
+  g_signal_connect (GTK_OBJECT (window), "realize",
+		    G_CALLBACK (_realize_callback), NULL);
   gtk_widget_realize (window);
 
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
@@ -1047,7 +1082,7 @@ void _set_geometry_hints(gboolean state)
   gint geom_mask = GDK_HINT_RESIZE_INC |
                    GDK_HINT_MIN_SIZE |
                    GDK_HINT_BASE_SIZE;
-  if (!sugar_detected())
+  if (!popt_sugar_look)
       geom_mask |= GDK_HINT_ASPECT;
   gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, &hints, geom_mask);
 }
@@ -1082,7 +1117,7 @@ void gc_fullscreen_set(gboolean state)
       gtk_window_set_decorated ( GTK_WINDOW ( window ), FALSE );
       gtk_window_set_type_hint ( GTK_WINDOW ( window ),
 				 GDK_WINDOW_TYPE_HINT_DESKTOP );
-      if (sugar_detected())
+      if (popt_sugar_look)
 	gtk_window_maximize ( GTK_WINDOW( window ) );
       else
         gtk_window_fullscreen ( GTK_WINDOW ( window ) );
@@ -1137,7 +1172,6 @@ static void cleanup()
   single_instance_release(); /* Must be done before property destroy */
   gc_board_stop();
   gc_db_exit();
-  sugar_cleanup();
   gc_fullscreen_set(FALSE);
   gc_menu_destroy();
   gc_net_destroy();
@@ -1197,21 +1231,17 @@ static void map_cb (GtkWidget *widget, gpointer data)
 
       gc_fullscreen_set(properties->fullscreen);
 
-      gc_bar_start(GTK_CONTAINER(workspace), GOO_CANVAS(canvas));
+      gc_status_init("");
 
       gc_board_init();
-
-      if (sugar_delayed_start())
-        gc_status_init(_("Retrieving remote data..."));
-      else
-      {
-      gc_status_init("");
       /* Load all the menu once */
       gc_menu_load();
       /* Save the root_menu */
       properties->menu_board = gc_menu_section_get(properties->root_menu);
-      gc_status_close();
 
+      gc_bar_start(GTK_CONTAINER(workspace), GOO_CANVAS(canvas));
+
+      gc_status_close();
 
       board_to_start = get_board_to_start();
 
@@ -1230,8 +1260,6 @@ static void map_cb (GtkWidget *widget, gpointer data)
       }
 
     }
-  }
-
   g_message("gcompris window is now mapped");
 }
 
@@ -1288,7 +1316,6 @@ static void load_properties ()
 
   /* Display the directory value we have */
   printf("package_data_dir         = %s\n", properties->package_data_dir);
-  printf("package_extra_data_dir   = %s\n", properties->package_extra_data_dir);
   printf("package_skin_dir         = %s\n", properties->package_skin_dir);
   printf("package_menu_dir         = %s\n", properties->menu_dir);
   printf("package_locale_dir       = %s\n", properties->package_locale_dir);
@@ -1419,7 +1446,6 @@ gc_update_canvas_zoom()
 static void
 start_bg_music (gchar *file)
 {
-  properties->music_paused = FALSE;
   g_message ("start_bg_music %s", file);
   gc_sound_bg_reopen();
 }
@@ -1508,8 +1534,6 @@ main (int argc, char *argv[])
 
   gtk_init (&argc, &argv);
 
-  sugar_setup(&argc, &argv);
-
   /* Argument parsing */
   context = g_option_context_new("GCompris");
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
@@ -1522,10 +1546,6 @@ main (int argc, char *argv[])
 		     | G_LOG_FLAG_RECURSION, gc_log_handler, NULL);
 
   /*------------------------------------------------------------*/
-
-  if (sugar_jobject_root_menu())
-    popt_root_menu = (gchar*)sugar_jobject_root_menu();
-
   if (popt_debug)
     {
       gc_debug = TRUE;
@@ -1606,13 +1626,6 @@ main (int argc, char *argv[])
       properties->fx = TRUE;
     }
 
-  if (popt_mute_music)
-    {
-      g_message("Music disabled");
-      properties->music = FALSE;
-    }
-
-
   if (popt_cursor)
     {
       g_message("Default system cursor enabled");
@@ -1663,12 +1676,6 @@ main (int argc, char *argv[])
     properties->package_data_dir = g_strdup(popt_package_data_dir);
   }
 
-  if (popt_package_extra_data_dir) {
-    printf("Overloaded package_extra_data_dir  = %s\n", popt_package_extra_data_dir);
-    g_free(properties->package_extra_data_dir);
-    properties->package_extra_data_dir = g_strdup(popt_package_extra_data_dir);
-  }
-
   if (popt_package_skin_dir) {
     printf("Overloaded package_skin_dir          = %s\n", popt_package_skin_dir);
     g_free(properties->package_skin_dir);
@@ -1818,8 +1825,7 @@ main (int argc, char *argv[])
     properties->music = FALSE;
     properties->fx = FALSE;
     g_message("Fullscreen and cursor is disabled");
-    if (!sugar_detected())
-      properties->fullscreen = FALSE;
+    properties->fullscreen = FALSE;
     properties->defaultcursor = GDK_LEFT_PTR;
   }
 
@@ -1884,8 +1890,6 @@ main (int argc, char *argv[])
     else
       gc_db_init(FALSE /* ENABLE DATABASE */);
 
-  sugar_setup_profile(popt_root_menu, popt_administration);
-
   /* An alternate profile is requested, check it does exists */
   if (popt_profile){
     properties->profile = gc_db_profile_from_name_get(popt_profile);
@@ -1917,6 +1921,17 @@ main (int argc, char *argv[])
     exit(0);
   }
 
+  if (popt_sugar_look){
+    #ifdef USE_SUGAR
+      extern Bar sugar_bar;
+      gc_bar_register(&sugar_bar);
+      extern Score sugar_score;
+      gc_score_register(&sugar_score);
+    #else
+	  printf("GCompris was not built with Sugar DE support.\n");
+      popt_sugar_look = FALSE;
+    #endif
+  }
 
   if (popt_no_zoom){
     g_message("Zoom disabled");
@@ -1943,8 +1958,6 @@ main (int argc, char *argv[])
 
   setup_window ();
 
-  sugar_setup_x11();
-
   gtk_widget_show_all (window);
 
 
@@ -1953,14 +1966,11 @@ main (int argc, char *argv[])
   else
     mute = TRUE;
 
-  properties->music_paused = FALSE;
-
   /* If a specific activity is selected, skeep the intro music */
   if(!popt_root_menu)
     {
       if (properties->music)
 	{
-      properties->music_paused = TRUE;
 	  gc_sound_play_ogg("music/intro.ogg",
 			    NULL);
 	  gc_sound_play_ogg_cb("voices/$LOCALE/misc/welcome.ogg",
@@ -1970,6 +1980,11 @@ main (int argc, char *argv[])
 	gc_sound_play_ogg("voices/$LOCALE/misc/welcome.ogg", NULL);
     }
 
+#ifndef WIN32
+  if (sugarActivityId)
+    gc_dbus_init(sugarActivityId);
+#endif
+
   gtk_main ();
 
   return(0);
