@@ -29,7 +29,6 @@
 
 #include "gcompris.h"
 #include "gc_core.h"
-#include "sugar_gc.h"
 
 #define SOUNDLISTFILE PACKAGE
 
@@ -109,18 +108,11 @@ gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
 			  void *user_context)
 {
 
-  GooCanvasItem *item;
   gint		 y_start = 0;
   gchar		*dataseturl = NULL;
 
   GtkWidget	*w;
 
-  if(sugar_detected())
-  {
-    sugar_choose_image(iscb, user_context);
-    return;
-  }
-
   if(rootitem)
     return;
 
@@ -136,7 +128,7 @@ gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
 
   images_selector_displayed = TRUE;
 
-  item = goo_canvas_svg_new (rootitem,
+  goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", "#IMAGE_SELECTOR",
 			     "pointer-events", GOO_CANVAS_EVENTS_NONE,
