@@ -174,7 +174,6 @@ gc_prop_new ()
   tmp->package_locale_dir         = NULL;
   tmp->package_plugin_dir         = NULL;
   tmp->package_python_plugin_dir  = NULL;
-  tmp->package_extra_data_dir     = NULL;
   tmp->menu_dir			  = NULL;
   tmp->system_icon_dir            = NULL;
   tmp->cache_dir                  = NULL;
@@ -182,7 +181,6 @@ gc_prop_new ()
   tmp->drag_mode                  = GC_DRAG_MODE_GRAB;
 
   tmp->zoom                       = 1;
-  tmp->music_paused               = 1;
 
   tmp->config_dir = gc_prop_default_config_directory_get();
   tmp->user_dir = gc_prop_default_user_directory_get();
@@ -531,7 +529,6 @@ gc_prop_destroy (GcomprisProperties *props)
   g_free(props->package_locale_dir);
   g_free(props->package_plugin_dir);
   g_free(props->package_python_plugin_dir);
-  g_free(props->package_extra_data_dir);
   g_free(props->menu_dir);
   g_free(props->system_icon_dir);
   g_free(props->cache_dir);
