@@ -47,7 +47,6 @@ typedef struct {
   gchar        *package_locale_dir;
   gchar        *package_plugin_dir;
   gchar        *package_python_plugin_dir;
-  gchar        *package_extra_data_dir;
   gchar        *menu_dir;
   gchar        *system_icon_dir;
   gchar        *cache_dir;
@@ -69,7 +68,6 @@ typedef struct {
   gchar        *server;
   gint		drag_mode;
   gint		zoom;
-  gint		music_paused;
 } GcomprisProperties;
 
 GcomprisProperties	*gc_prop_get (void);
